@@ -61,7 +61,7 @@ ScoreWindow::~ScoreWindow()
 void ScoreWindow::setup(Score *score, Course *course)
 {
     TRACE;
-    QString title = QString("Score: %1, %2 - %3").arg(score->getClubName()).arg(score->getCourseName()).arg(score->getDate());
+    QString title = QString("%1, %2 - %3").arg(score->getClubName()).arg(score->getCourseName()).arg(score->getDate());
     setWindowTitle(title);
     model->set(score, course);
 }
